garrett_example: #Example Dataset for Garrett Ranking

garrett_exampleR Documentation

#Example Dataset for Garrett Ranking

Description

#Example Dataset for Garrett Ranking

Usage

garrett_example

Format

A data frame with 50 rows and 23 columns:

Respondent

The name or serial number identifying each respondent.

C1

Rank assigned to constraint 1.

C2

Rank assigned to constraint 2.

C3

Rank assigned to constraint 3.

C4

Rank assigned to constraint 4.

C5

Rank assigned to constraint 5.

C6

Rank assigned to constraint 6.

C7

Rank assigned to constraint 7.

C8

Rank assigned to constraint 8.

C9

Rank assigned to constraint 9.

C10

Rank assigned to constraint 10.

C11

Rank assigned to constraint 11.

C12

Rank assigned to constraint 12.

C13

Rank assigned to constraint 13.

C14

Rank assigned to constraint 14.

C15

Rank assigned to constraint 15.

C16

Rank assigned to constraint 16.

C17

Rank assigned to constraint 17.

C18

Rank assigned to constraint 18.

C19

Rank assigned to constraint 19.

C20

Rank assigned to constraint 20.

C21

Rank assigned to constraint 21.

C22

Rank assigned to constraint 22.

Details

The first column contains the respondent's name or serial number. The remaining 22 columns (C1 to C22) contain the ranks assigned by each respondent to the corresponding constraints. There are 50 respondents in the dataset. No tied ranks are present in the dataset.

An example dataset demonstrating the application of the Garrett ranking method.

The dataset contains ranking responses from 50 respondents for 22 constraints.

Examples

data(garrett_example)
#Run Garrett ranking analysis
result <- garrett_rank(garrett_example,respondent = "Respondent")
summary(result)
result$ranking
result$frequency
result$weighted_scores
#Select the plot type
plot(result, type = "bar")
plot(result, type = "lollipop")
plot(result, type = "dot")
plot(result, type = "line")
plot(result, type = "heatmap")
plot(result, type = "cluster")
plot(result,type="contribution")
plot(result, type = "cluster", k = 3)
plot(result,type = "cluster",scale = "row",show_numbers = TRUE)

#Run Kendall's Coefficient of Concordance
kw<-kendall_w(garrett_example,respondent = "Respondent")
summary(kw)

GarrettRank documentation built on Oct. 6, 2026, 5:07 p.m.