garrett_table: Garrett Conversion Table It is a standard Garrett conversion...

View source: R/garrett_rank.R

garrett_tableR Documentation

Garrett Conversion Table It is a standard Garrett conversion table used by the package.

Description

Garrett Conversion Table It is a standard Garrett conversion table used by the package.

Usage

garrett_table()

Value

A data.frame with two columns:

Percent_Position

The percent position values used to determine Garrett scores from respondent ranks.

Garrett_Score

The corresponding Garrett scores assigned to the percent positions.

Examples


table<-garrett_table()
print(table)


GarrettRank documentation built on Oct. 6, 2026, 5:07 p.m.