| .validate_ranking_data | R Documentation |
Validates respondent ranking data before Garrett ranking analysis. The function checks the input data structure, ranking values, and completeness of ranks for each respondent. Supported input formats include data frames, matrices, CSV files, and Excel files.
.validate_ranking_data(data, respondent = NULL)
data |
A data.frame, matrix, CSV file path, or Excel file path containing respondent ranking data. Each row represents a respondent and each column represents a factor or item being ranked. |
respondent |
Optional respondent ID column name or column position to exclude from the ranking data before validation. |
A validated data frame containing the ranking data after checking that the data have valid dimensions, numeric integer ranks, and that each respondent assigns every rank exactly once.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.