| garrett_table | R Documentation |
Garrett Conversion Table It is a standard Garrett conversion table used by the package.
garrett_table()
A data.frame with two columns:
The percent position values used to determine Garrett scores from respondent ranks.
The corresponding Garrett scores assigned to the percent positions.
table<-garrett_table()
print(table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.